@@ -4,7 +4,7 @@ import (
 	"bytes"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
+	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-vfs/v4/vfst"
 
@@ -14,19 +14,19 @@ import (
 func TestKernel(t *testing.T) {
 	for _, tc := range []struct {
 		name           string
-		root           interface{}
-		expectedKernel map[string]interface{}
+		root           any
+		expectedKernel map[string]any
 	}{
 		{
 			name: "windows_services_for_linux",
-			root: map[string]interface{}{
-				"/proc/sys/kernel": map[string]interface{}{
+			root: map[string]any{
+				"/proc/sys/kernel": map[string]any{
 					"osrelease": "4.19.81-microsoft-standard\n",
 					"ostype":    "Linux\n",
 					"version":   "#1 SMP Debian 5.2.9-2 (2019-08-21)\n",
 				},
 			},
-			expectedKernel: map[string]interface{}{
+			expectedKernel: map[string]any{
 				"osrelease": "4.19.81-microsoft-standard",
 				"ostype":    "Linux",
 				"version":   "#1 SMP Debian 5.2.9-2 (2019-08-21)",
@@ -34,18 +34,18 @@ func TestKernel(t *testing.T) {
 		},
 		{
 			name: "debian_version_only",
-			root: map[string]interface{}{
-				"/proc/sys/kernel": map[string]interface{}{
+			root: map[string]any{
+				"/proc/sys/kernel": map[string]any{
 					"version": "#1 SMP Debian 5.2.9-2 (2019-08-21)\n",
 				},
 			},
-			expectedKernel: map[string]interface{}{
+			expectedKernel: map[string]any{
 				"version": "#1 SMP Debian 5.2.9-2 (2019-08-21)",
 			},
 		},
 		{
 			name: "proc_sys_kernel_missing",
-			root: map[string]interface{}{
+			root: map[string]any{
 				"/proc/sys": &vfst.Dir{Perm: 0o755},
 			},
 			expectedKernel: nil,
@@ -64,12 +64,12 @@ func TestKernel(t *testing.T) {
 func TestOSRelease(t *testing.T) {
 	for _, tc := range []struct {
 		name     string
-		root     map[string]interface{}
-		expected map[string]interface{}
+		root     map[string]any
+		expected map[string]any
 	}{
 		{
 			name: "archlinux",
-			root: map[string]interface{}{
+			root: map[string]any{
 				"/usr/lib/os-release": chezmoitest.JoinLines(
 					`NAME="Arch Linux"`,
 					`PRETTY_NAME="Arch Linux"`,
@@ -83,7 +83,7 @@ func TestOSRelease(t *testing.T) {
 					`LOGO=archlinux`,
 				),
 			},
-			expected: map[string]interface{}{
+			expected: map[string]any{
 				"NAME":              "Arch Linux",
 				"PRETTY_NAME":       "Arch Linux",
 				"ID":                "arch",
@@ -98,7 +98,7 @@ func TestOSRelease(t *testing.T) {
 		},
 		{
 			name: "fedora",
-			root: map[string]interface{}{
+			root: map[string]any{
 				"/etc/os-release": chezmoitest.JoinLines(
 					`NAME=Fedora`,
 					`VERSION="17 (Beefy Miracle)"`,
@@ -111,7 +111,7 @@ func TestOSRelease(t *testing.T) {
 					`BUG_REPORT_URL="https://bugzilla.redhat.com/"`,
 				),
 			},
-			expected: map[string]interface{}{
+			expected: map[string]any{
 				"NAME":           "Fedora",
 				"VERSION":        "17 (Beefy Miracle)",
 				"ID":             "fedora",
@@ -125,7 +125,7 @@ func TestOSRelease(t *testing.T) {
 		},
 		{
 			name: "ubuntu",
-			root: map[string]interface{}{
+			root: map[string]any{
 				"/usr/lib/os-release": chezmoitest.JoinLines(
 					`NAME="Ubuntu"`,
 					`VERSION="18.04.1 LTS (Bionic Beaver)"`,
@@ -141,7 +141,7 @@ func TestOSRelease(t *testing.T) {
 					`UBUNTU_CODENAME=bionic`,
 				),
 			},
-			expected: map[string]interface{}{
+			expected: map[string]any{
 				"NAME":               "Ubuntu",
 				"VERSION":            "18.04.1 LTS (Bionic Beaver)",
 				"ID":                 "ubuntu",
@@ -159,8 +159,7 @@ func TestOSRelease(t *testing.T) {
 	} {
 		t.Run(tc.name, func(t *testing.T) {
 			chezmoitest.WithTestFS(t, tc.root, func(fileSystem vfs.FS) {
-				system := NewRealSystem(fileSystem)
-				actual, err := OSRelease(system)
+				actual, err := OSRelease(fileSystem)
 				assert.NoError(t, err)
 				assert.Equal(t, tc.expected, actual)
 			})
@@ -172,7 +171,7 @@ func TestParseOSRelease(t *testing.T) {
 	for _, tc := range []struct {
 		name     string
 		s        string
-		expected map[string]interface{}
+		expected map[string]any
 	}{
 		{
 			name: "fedora",
@@ -187,7 +186,7 @@ func TestParseOSRelease(t *testing.T) {
 				`HOME_URL="https://fedoraproject.org/"`,
 				`BUG_REPORT_URL="https://bugzilla.redhat.com/"`,
 			),
-			expected: map[string]interface{}{
+			expected: map[string]any{
 				"NAME":           "Fedora",
 				"VERSION":        "17 (Beefy Miracle)",
 				"ID":             "fedora",
@@ -218,7 +217,7 @@ func TestParseOSRelease(t *testing.T) {
 				`VERSION_CODENAME=bionic`,
 				`UBUNTU_CODENAME=bionic`,
 			),
-			expected: map[string]interface{}{
+			expected: map[string]any{
 				"NAME":               "Ubuntu",
 				"VERSION":            "18.04.1 LTS (Bionic Beaver)",
 				"ID":                 "ubuntu",
