@@ -11,17 +11,32 @@ import (
 	vfs "github.com/twpayne/go-vfs/v4"
 )
 
+type patternSetIncludeType bool
+
+const (
+	patternSetInclude patternSetIncludeType = true
+	patternSetExclude patternSetIncludeType = false
+)
+
+type patternSetMatchType int
+
+const (
+	patternSetMatchInclude patternSetMatchType = 1
+	patternSetMatchUnknown patternSetMatchType = 0
+	patternSetMatchExclude patternSetMatchType = -1
+)
+
 // An patternSet is a set of patterns.
 type patternSet struct {
-	includePatterns stringSet
-	excludePatterns stringSet
+	includePatterns set[string]
+	excludePatterns set[string]
 }
 
 // newPatternSet returns a new patternSet.
 func newPatternSet() *patternSet {
 	return &patternSet{
-		includePatterns: newStringSet(),
-		excludePatterns: newStringSet(),
+		includePatterns: newSet[string](),
+		excludePatterns: newSet[string](),
 	}
 }
 
@@ -36,13 +51,14 @@ func (ps *patternSet) MarshalZerologObject(e *zerolog.Event) {
 }
 
 // add adds a pattern to ps.
-func (ps *patternSet) add(pattern string, include bool) error {
+func (ps *patternSet) add(pattern string, include patternSetIncludeType) error {
 	if ok := doublestar.ValidatePattern(pattern); !ok {
 		return fmt.Errorf("%s: invalid pattern", pattern)
 	}
-	if include {
+	switch include {
+	case patternSetInclude:
 		ps.includePatterns.add(pattern)
-	} else {
+	case patternSetExclude:
 		ps.excludePatterns.add(pattern)
 	}
 	return nil
@@ -50,10 +66,9 @@ func (ps *patternSet) add(pattern string, include bool) error {
 
 // glob returns all matches in fileSystem.
 func (ps *patternSet) glob(fileSystem vfs.FS, prefix string) ([]string, error) {
-	// FIXME use AbsPath and RelPath
-	allMatches := newStringSet()
+	allMatches := newSet[string]()
 	for includePattern := range ps.includePatterns {
-		matches, err := doublestar.Glob(fileSystem, prefix+includePattern)
+		matches, err := Glob(fileSystem, filepath.ToSlash(prefix+includePattern))
 		if err != nil {
 			return nil, err
 		}
@@ -72,23 +87,38 @@ func (ps *patternSet) glob(fileSystem vfs.FS, prefix string) ([]string, error) {
 	}
 	matchesSlice := allMatches.elements()
 	for i, match := range matchesSlice {
-		matchesSlice[i] = mustTrimPrefix(filepath.ToSlash(match), prefix)
+		matchesSlice[i] = filepath.ToSlash(match)[len(prefix):]
 	}
 	sort.Strings(matchesSlice)
 	return matchesSlice, nil
 }
 
-// match returns if name matches any pattern in ps.
-func (ps *patternSet) match(name string) bool {
+// match returns if name matches ps.
+func (ps *patternSet) match(name string) patternSetMatchType {
+	// If name is explicitly excluded, then return exclude.
 	for pattern := range ps.excludePatterns {
 		if ok, _ := doublestar.Match(pattern, name); ok {
-			return false
+			return patternSetMatchExclude
 		}
 	}
+
+	// If name is explicitly included, then return include.
 	for pattern := range ps.includePatterns {
 		if ok, _ := doublestar.Match(pattern, name); ok {
-			return true
+			return patternSetMatchInclude
 		}
 	}
-	return false
+
+	// If name did not match any include or exclude patterns...
+	switch {
+	case len(ps.includePatterns) > 0 && len(ps.excludePatterns) == 0:
+		// ...only include patterns were specified, so exclude by default.
+		return patternSetMatchExclude
+	case len(ps.includePatterns) == 0 && len(ps.excludePatterns) > 0:
+		// ...only exclude patterns were specified, so include by default.
+		return patternSetMatchInclude
+	default:
+		// ...both include and exclude were specified, so return unknown.
+		return patternSetMatchUnknown
+	}
 }
