@@ -2,26 +2,53 @@ package chezmoi
 
 import (
 	"encoding/hex"
+	"os/exec"
 
 	"github.com/rs/zerolog"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 )
 
+// A SourceAttr contains attributes of the source.
+type SourceAttr struct {
+	Condition ScriptCondition
+	Encrypted bool
+	External  bool
+	Template  bool
+}
+
+// A SourceStateOrigin represents the origin of a source state.
+type SourceStateOrigin interface {
+	Path() AbsPath
+	OriginString() string
+}
+
+// A SourceStateOriginAbsPath is an absolute path.
+type SourceStateOriginAbsPath AbsPath
+
 // A SourceStateEntry represents the state of an entry in the source state.
 type SourceStateEntry interface {
 	zerolog.LogObjectMarshaler
 	Evaluate() error
 	Order() ScriptOrder
-	Origin() string
+	Origin() SourceStateOrigin
 	SourceRelPath() SourceRelPath
 	TargetStateEntry(destSystem System, destDirAbsPath AbsPath) (TargetStateEntry, error)
 }
 
+// A SourceStateCommand represents a command that should be run.
+type SourceStateCommand struct {
+	cmd           *exec.Cmd
+	origin        SourceStateOrigin
+	forceRefresh  bool
+	refreshPeriod Duration
+	sourceAttr    SourceAttr
+}
+
 // A SourceStateDir represents the state of a directory in the source state.
 type SourceStateDir struct {
 	Attr             DirAttr
-	origin           string
+	origin           SourceStateOrigin
 	sourceRelPath    SourceRelPath
 	targetStateEntry TargetStateEntry
 }
@@ -30,7 +57,7 @@ type SourceStateDir struct {
 type SourceStateFile struct {
 	*lazyContents
 	Attr                 FileAttr
-	origin               string
+	origin               SourceStateOrigin
 	sourceRelPath        SourceRelPath
 	targetStateEntryFunc targetStateEntryFunc
 	targetStateEntry     TargetStateEntry
@@ -39,10 +66,59 @@ type SourceStateFile struct {
 
 // A SourceStateRemove represents that an entry should be removed.
 type SourceStateRemove struct {
+	origin        SourceStateOrigin
 	sourceRelPath SourceRelPath
 	targetRelPath RelPath
 }
 
+// A SourceStateOriginRemove is used for removes. The source of the remove is
+// not currently tracked. The remove could come from an exact_ directory, a
+// non-empty_ file with empty contents, or one of many patterns in many
+// .chezmoiignore files.
+//
+// FIXME remove this when the sources of all removes are tracked.
+type SourceStateOriginRemove struct{}
+
+// Evaluate evaluates s and returns any error.
+func (s *SourceStateCommand) Evaluate() error {
+	return nil
+}
+
+// MarshalZerologObject implements
+// github.com/rs/zerolog.LogObjectMarshaler.MarshalZerologObject.
+func (s *SourceStateCommand) MarshalZerologObject(e *zerolog.Event) {
+	e.EmbedObject(chezmoilog.OSExecCmdLogObject{Cmd: s.cmd})
+	e.Str("origin", s.origin.OriginString())
+}
+
+// Order returns s's order.
+func (s *SourceStateCommand) Order() ScriptOrder {
+	return ScriptOrderDuring
+}
+
+// Origin returns s's origin.
+func (s *SourceStateCommand) Origin() SourceStateOrigin {
+	return s.origin
+}
+
+// SourceRelPath returns s's source relative path.
+func (s *SourceStateCommand) SourceRelPath() SourceRelPath {
+	return emptySourceRelPath
+}
+
+// TargetStateEntry returns s's target state entry.
+func (s *SourceStateCommand) TargetStateEntry(
+	destSystem System,
+	destDirAbsPath AbsPath,
+) (TargetStateEntry, error) {
+	return &TargetStateModifyDirWithCmd{
+		cmd:           s.cmd,
+		forceRefresh:  s.forceRefresh,
+		refreshPeriod: s.refreshPeriod,
+		sourceAttr:    s.sourceAttr,
+	}, nil
+}
+
 // Evaluate evaluates s and returns any error.
 func (s *SourceStateDir) Evaluate() error {
 	return nil
@@ -61,7 +137,7 @@ func (s *SourceStateDir) Order() ScriptOrder {
 }
 
 // Origin returns s's origin.
-func (s *SourceStateDir) Origin() string {
+func (s *SourceStateDir) Origin() SourceStateOrigin {
 	return s.origin
 }
 
@@ -71,7 +147,10 @@ func (s *SourceStateDir) SourceRelPath() SourceRelPath {
 }
 
 // TargetStateEntry returns s's target state entry.
-func (s *SourceStateDir) TargetStateEntry(destSystem System, destDirAbsPath AbsPath) (TargetStateEntry, error) {
+func (s *SourceStateDir) TargetStateEntry(
+	destSystem System,
+	destDirAbsPath AbsPath,
+) (TargetStateEntry, error) {
 	return s.targetStateEntry, nil
 }
 
@@ -105,7 +184,7 @@ func (s *SourceStateFile) Order() ScriptOrder {
 }
 
 // Origin returns s's origin.
-func (s *SourceStateFile) Origin() string {
+func (s *SourceStateFile) Origin() SourceStateOrigin {
 	return s.origin
 }
 
@@ -115,9 +194,15 @@ func (s *SourceStateFile) SourceRelPath() SourceRelPath {
 }
 
 // TargetStateEntry returns s's target state entry.
-func (s *SourceStateFile) TargetStateEntry(destSystem System, destDirAbsPath AbsPath) (TargetStateEntry, error) {
+func (s *SourceStateFile) TargetStateEntry(
+	destSystem System,
+	destDirAbsPath AbsPath,
+) (TargetStateEntry, error) {
 	if s.targetStateEntryFunc != nil {
-		s.targetStateEntry, s.targetStateEntryErr = s.targetStateEntryFunc(destSystem, destDirAbsPath)
+		s.targetStateEntry, s.targetStateEntryErr = s.targetStateEntryFunc(
+			destSystem,
+			destDirAbsPath,
+		)
 		s.targetStateEntryFunc = nil
 	}
 	return s.targetStateEntry, s.targetStateEntryErr
@@ -139,8 +224,8 @@ func (s *SourceStateRemove) Order() ScriptOrder {
 }
 
 // Origin returns s's origin.
-func (s *SourceStateRemove) Origin() string {
-	return s.sourceRelPath.String()
+func (s *SourceStateRemove) Origin() SourceStateOrigin {
+	return s.origin
 }
 
 // SourceRelPath returns s's source relative path.
@@ -149,6 +234,29 @@ func (s *SourceStateRemove) SourceRelPath() SourceRelPath {
 }
 
 // TargetStateEntry returns s's target state entry.
-func (s *SourceStateRemove) TargetStateEntry(destSystem System, destDirAbsPath AbsPath) (TargetStateEntry, error) {
+func (s *SourceStateRemove) TargetStateEntry(
+	destSystem System,
+	destDirAbsPath AbsPath,
+) (TargetStateEntry, error) {
 	return &TargetStateRemove{}, nil
 }
+
+// Path returns s's path.
+func (s SourceStateOriginAbsPath) Path() AbsPath {
+	return AbsPath(s)
+}
+
+// OriginString returns s's origin.
+func (s SourceStateOriginAbsPath) OriginString() string {
+	return AbsPath(s).String()
+}
+
+// Path returns s's path.
+func (s SourceStateOriginRemove) Path() AbsPath {
+	return EmptyAbsPath
+}
+
+// OriginString returns s's origin.
+func (s SourceStateOriginRemove) OriginString() string {
+	return "remove"
+}
