@@ -1,10 +1,12 @@
 package chezmoi
 
 import (
-	"archive/zip"
 	"io"
 	"io/fs"
+	"os/exec"
 	"time"
+
+	"github.com/klauspost/compress/zip"
 )
 
 // A ZIPWriterSystem is a System that writes to a ZIP archive.
@@ -40,41 +42,51 @@ func (s *ZIPWriterSystem) Mkdir(name AbsPath, perm fs.FileMode) error {
 	return err
 }
 
+// RunCmd implements System.RunCmd.
+func (s *ZIPWriterSystem) RunCmd(cmd *exec.Cmd) error {
+	return nil
+}
+
 // RunScript implements System.RunScript.
-func (s *ZIPWriterSystem) RunScript(scriptname RelPath, dir AbsPath, data []byte, interpreter *Interpreter) error {
+func (s *ZIPWriterSystem) RunScript(
+	scriptname RelPath,
+	dir AbsPath,
+	data []byte,
+	options RunScriptOptions,
+) error {
 	return s.WriteFile(NewAbsPath(scriptname.String()), data, 0o700)
 }
 
 // WriteFile implements System.WriteFile.
 func (s *ZIPWriterSystem) WriteFile(filename AbsPath, data []byte, perm fs.FileMode) error {
-	fh := zip.FileHeader{
+	fileHeader := zip.FileHeader{
 		Name:               filename.String(),
 		Method:             zip.Deflate,
 		Modified:           s.modified,
 		UncompressedSize64: uint64(len(data)),
 	}
-	fh.SetMode(perm)
-	fw, err := s.zipWriter.CreateHeader(&fh)
+	fileHeader.SetMode(perm)
+	fileWriter, err := s.zipWriter.CreateHeader(&fileHeader)
 	if err != nil {
 		return err
 	}
-	_, err = fw.Write(data)
+	_, err = fileWriter.Write(data)
 	return err
 }
 
 // WriteSymlink implements System.WriteSymlink.
 func (s *ZIPWriterSystem) WriteSymlink(oldname string, newname AbsPath) error {
 	data := []byte(oldname)
-	fh := zip.FileHeader{
+	fileHeader := zip.FileHeader{
 		Name:               newname.String(),
 		Modified:           s.modified,
 		UncompressedSize64: uint64(len(data)),
 	}
-	fh.SetMode(fs.ModeSymlink)
-	fw, err := s.zipWriter.CreateHeader(&fh)
+	fileHeader.SetMode(fs.ModeSymlink)
+	fileWriter, err := s.zipWriter.CreateHeader(&fileHeader)
 	if err != nil {
 		return err
 	}
-	_, err = fw.Write(data)
+	_, err = fileWriter.Write(data)
 	return err
 }
