@@ -18,14 +18,21 @@ func (c *Config) newCatCmd() *cobra.Command {
 		ValidArgsFunction: c.targetValidArgs,
 		Args:              cobra.MinimumNArgs(1),
 		RunE:              c.makeRunEWithSourceState(c.runCatCmd),
+		Annotations: newAnnotations(
+			requiresSourceDirectory,
+		),
 	}
 
 	return catCmd
 }
 
-func (c *Config) runCatCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
+func (c *Config) runCatCmd(
+	cmd *cobra.Command,
+	args []string,
+	sourceState *chezmoi.SourceState,
+) error {
 	targetRelPaths, err := c.targetRelPaths(sourceState, args, targetRelPathsOptions{
-		mustBeInSourceState: true,
+		mustBeManaged: true,
 	})
 	if err != nil {
 		return err
@@ -34,7 +41,10 @@ func (c *Config) runCatCmd(cmd *cobra.Command, args []string, sourceState *chezm
 	builder := strings.Builder{}
 	for _, targetRelPath := range targetRelPaths {
 		sourceStateEntry := sourceState.MustEntry(targetRelPath)
-		targetStateEntry, err := sourceStateEntry.TargetStateEntry(c.destSystem, c.DestDirAbsPath.Join(targetRelPath))
+		targetStateEntry, err := sourceStateEntry.TargetStateEntry(
+			c.destSystem,
+			c.DestDirAbsPath.Join(targetRelPath),
+		)
 		if err != nil {
 			return fmt.Errorf("%s: %w", targetRelPath, err)
 		}
