@@ -384,8 +384,9 @@ func newConfig(options ...configOption) (*Config, error) {
 		stderr: os.Stderr,
 	}
 
-	// Override sprig's toPrettyJson template function. Delete it from the
-	// template function map first to avoid a duplication function panic.
+	// Override sprig template functions. Delete them from the template function
+	// map first to avoid a duplicate function panic.
+	delete(c.templateFuncs, "fromJson")
 	delete(c.templateFuncs, "toPrettyJson")
 
 	// The completion template function is added in persistentPreRunRootE as
@@ -413,6 +414,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		"findExecutable":           c.findExecutableTemplateFunc,
 		"findOneExecutable":        c.findOneExecutableTemplateFunc,
 		"fromIni":                  c.fromIniTemplateFunc,
+		"fromJson":                 c.fromJsonTemplateFunc,
 		"fromJsonc":                c.fromJsoncTemplateFunc,
 		"fromToml":                 c.fromTomlTemplateFunc,
 		"fromYaml":                 c.fromYamlTemplateFunc,
@@ -1732,6 +1734,10 @@ func (c *Config) newSourceState(
 		return nil, err
 	}
 
+	if err := c.runHookPre(readSourceStateHookName); err != nil {
+		return nil, err
+	}
+
 	sourceState := chezmoi.NewSourceState(append([]chezmoi.SourceStateOption{
 		chezmoi.WithBaseSystem(c.baseSystem),
 		chezmoi.WithCacheDir(c.CacheDirAbsPath),
@@ -1760,6 +1766,10 @@ func (c *Config) newSourceState(
 		return nil, err
 	}
 
+	if err := c.runHookPost(readSourceStateHookName); err != nil {
+		return nil, err
+	}
+
 	return sourceState, nil
 }
 
@@ -1831,10 +1841,8 @@ func (c *Config) persistentPostRunRootE(cmd *cobra.Command, args []string) error
 		}
 	}
 
-	if command := c.Hooks[cmd.Name()].Post; command.Command != "" {
-		if err := c.run(c.homeDirAbsPath, command.Command, command.Args); err != nil {
-			return err
-		}
+	if err := c.runHookPost(cmd.Name()); err != nil {
+		return err
 	}
 
 	return nil
@@ -2183,10 +2191,8 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		os.Setenv(key, value)
 	}
 
-	if command := c.Hooks[cmd.Name()].Pre; command.Command != "" {
-		if err := c.run(c.homeDirAbsPath, command.Command, command.Args); err != nil {
-			return err
-		}
+	if err := c.runHookPre(cmd.Name()); err != nil {
+		return err
 	}
 
 	return nil
@@ -2403,6 +2409,24 @@ func (c *Config) runEditor(args []string) error {
 	return err
 }
 
+// runHookPost runs the hook's post command, if it is set.
+func (c *Config) runHookPost(hook string) error {
+	command := c.Hooks[hook].Post
+	if command.Command == "" {
+		return nil
+	}
+	return c.run(c.homeDirAbsPath, command.Command, command.Args)
+}
+
+// runHookPre runs the hook's pre command, if it is set.
+func (c *Config) runHookPre(hook string) error {
+	command := c.Hooks[hook].Pre
+	if command.Command == "" {
+		return nil
+	}
+	return c.run(c.homeDirAbsPath, command.Command, command.Args)
+}
+
 // setEncryption configures c's encryption.
 func (c *Config) setEncryption() error {
 	switch c.Encryption {
