@@ -4,8 +4,7 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v4"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
@@ -15,11 +14,11 @@ import (
 func TestDataCmd(t *testing.T) {
 	for _, tc := range []struct {
 		format chezmoi.Format
-		root   map[string]interface{}
+		root   map[string]any
 	}{
 		{
 			format: chezmoi.FormatJSON,
-			root: map[string]interface{}{
+			root: map[string]any{
 				"/home/user/.config/chezmoi/chezmoi.json": chezmoitest.JoinLines(
 					`{`,
 					`  "sourceDir": "/tmp/source",`,
@@ -32,7 +31,7 @@ func TestDataCmd(t *testing.T) {
 		},
 		{
 			format: chezmoi.FormatYAML,
-			root: map[string]interface{}{
+			root: map[string]any{
 				"/home/user/.config/chezmoi/chezmoi.yaml": chezmoitest.JoinLines(
 					`sourceDir: /tmp/source`,
 					`data:`,
@@ -50,7 +49,7 @@ func TestDataCmd(t *testing.T) {
 				config := newTestConfig(t, fileSystem)
 				builder := strings.Builder{}
 				config.stdout = &builder
-				require.NoError(t, config.execute(args))
+				assert.NoError(t, config.execute(args))
 
 				var data struct {
 					Chezmoi struct {
@@ -60,7 +59,7 @@ func TestDataCmd(t *testing.T) {
 				}
 				assert.NoError(t, tc.format.Unmarshal([]byte(builder.String()), &data))
 				normalizedSourceDir, err := chezmoi.NormalizePath("/tmp/source")
-				require.NoError(t, err)
+				assert.NoError(t, err)
 				assert.Equal(t, normalizedSourceDir.String(), data.Chezmoi.SourceDir)
 				assert.True(t, data.Test)
 			})
