@@ -4,23 +4,23 @@ import (
 	"bytes"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v4"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
 )
 
 func TestManagedCmd(t *testing.T) {
+	templateContents := `{{ fail "Template should not be executed" }}`
 	for _, tc := range []struct {
 		name           string
-		root           interface{}
+		root           any
 		args           []string
 		expectedOutput string
 	}{
 		{
 			name: "simple",
-			root: map[string]interface{}{
+			root: map[string]any{
 				"/home/user/.local/share/chezmoi/dot_file": "# contents of .file\n",
 			},
 			expectedOutput: chezmoitest.JoinLines(
@@ -29,8 +29,8 @@ func TestManagedCmd(t *testing.T) {
 		},
 		{
 			name: "template",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi/dot_template.tmpl": "{{ fail \"Template should not be executed\" }}\n",
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi/dot_template.tmpl": templateContents,
 			},
 			expectedOutput: chezmoitest.JoinLines(
 				".template",
@@ -38,8 +38,8 @@ func TestManagedCmd(t *testing.T) {
 		},
 		{
 			name: "create_template",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi/create_dot_file.tmpl": "{{ fail \"Template should not be executed\" }}\n",
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi/create_dot_file.tmpl": templateContents,
 			},
 			expectedOutput: chezmoitest.JoinLines(
 				".file",
@@ -47,20 +47,34 @@ func TestManagedCmd(t *testing.T) {
 		},
 		{
 			name: "modify_template",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi/modify_dot_file.tmpl": "{{ fail \"Template should not be executed\" }}\n",
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi/modify_dot_file.tmpl": templateContents,
 			},
 			expectedOutput: chezmoitest.JoinLines(
 				".file",
 			),
 		},
+		{
+			name: "remove",
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".local/share/chezmoi/.chezmoiremove": chezmoitest.JoinLines(
+						".remove",
+					),
+					".remove": "",
+				},
+			},
+			expectedOutput: chezmoitest.JoinLines(
+				".remove",
+			),
+		},
 		{
 			name: "script_template",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi/run_script.tmpl": "{{ fail \"Template should not be executed\" }}\n",
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi/run_script.tmpl": templateContents,
 			},
 			args: []string{
-				"--include", "scripts",
+				"--include", "always,scripts",
 			},
 			expectedOutput: chezmoitest.JoinLines(
 				"script",
@@ -68,18 +82,38 @@ func TestManagedCmd(t *testing.T) {
 		},
 		{
 			name: "symlink_template",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi/symlink_dot_symlink.tmpl": "{{ fail \"Template should not be executed\" }}\n",
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi/symlink_dot_symlink.tmpl": templateContents,
 			},
 			expectedOutput: chezmoitest.JoinLines(
 				".symlink",
 			),
 		},
+		{
+			name: "external_git_repo",
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi/.chezmoiexternal.toml": chezmoitest.JoinLines(
+					`[".dir"]`,
+					`    type = "git-repo"`,
+					`    url = "https://github.com/example/example.git"`,
+				),
+			},
+			expectedOutput: chezmoitest.JoinLines(
+				".dir",
+			),
+		},
 	} {
 		t.Run(tc.name, func(t *testing.T) {
 			chezmoitest.WithTestFS(t, tc.root, func(fileSystem vfs.FS) {
 				stdout := &bytes.Buffer{}
-				require.NoError(t, newTestConfig(t, fileSystem, withStdout(stdout)).execute(append([]string{"managed"}, tc.args...)))
+				assert.NoError(
+					t,
+					newTestConfig(
+						t,
+						fileSystem,
+						withStdout(stdout),
+					).execute(append([]string{"managed"}, tc.args...)),
+				)
 				assert.Equal(t, tc.expectedOutput, stdout.String())
 			})
 		})
