@@ -2,51 +2,35 @@ package cmd
 
 import (
 	"bytes"
-	"fmt"
+	"os"
 	"os/exec"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 )
 
 type passConfig struct {
-	Command string
+	Command string `json:"command" mapstructure:"command" yaml:"command"`
 	cache   map[string][]byte
 }
 
-func (c *Config) passOutput(id string) []byte {
-	if output, ok := c.Pass.cache[id]; ok {
-		return output
-	}
-
-	name := c.Pass.Command
-	args := []string{"show", id}
-	cmd := exec.Command(name, args...)
-	cmd.Stdin = c.stdin
-	cmd.Stderr = c.stderr
-	output, err := c.baseSystem.IdempotentCmdOutput(cmd)
-	if err != nil {
-		returnTemplateError(fmt.Errorf("%s: %w", shellQuoteCommand(name, args), err))
-		return nil
-	}
-
-	if c.Pass.cache == nil {
-		c.Pass.cache = make(map[string][]byte)
-	}
-	c.Pass.cache[id] = output
-
-	return output
-}
-
 func (c *Config) passTemplateFunc(id string) string {
-	output, _, _ := chezmoi.CutBytes(c.passOutput(id), []byte{'\n'})
-	return string(bytes.TrimSpace(output))
+	output, err := c.passOutput(id)
+	if err != nil {
+		panic(err)
+	}
+	firstLine, _, _ := bytes.Cut(output, []byte{'\n'})
+	return string(bytes.TrimSpace(firstLine))
 }
 
 func (c *Config) passFieldsTemplateFunc(id string) map[string]string {
-	output := c.passOutput(id)
+	output, err := c.passOutput(id)
+	if err != nil {
+		panic(err)
+	}
+
 	result := make(map[string]string)
 	for _, line := range bytes.Split(output, []byte{'\n'}) {
-		if key, value, ok := chezmoi.CutBytes(line, []byte{':'}); ok {
+		if key, value, ok := bytes.Cut(line, []byte{':'}); ok {
 			result[string(bytes.TrimSpace(key))] = string(bytes.TrimSpace(value))
 		}
 	}
@@ -54,5 +38,31 @@ func (c *Config) passFieldsTemplateFunc(id string) map[string]string {
 }
 
 func (c *Config) passRawTemplateFunc(id string) string {
-	return string(c.passOutput(id))
+	output, err := c.passOutput(id)
+	if err != nil {
+		panic(err)
+	}
+	return string(output)
+}
+
+func (c *Config) passOutput(id string) ([]byte, error) {
+	if output, ok := c.Pass.cache[id]; ok {
+		return output, nil
+	}
+
+	args := []string{"show", id}
+	cmd := exec.Command(c.Pass.Command, args...) //nolint:gosec
+	cmd.Stdin = os.Stdin
+	cmd.Stderr = os.Stderr
+	output, err := chezmoilog.LogCmdOutput(cmd)
+	if err != nil {
+		return nil, newCmdOutputError(cmd, output, err)
+	}
+
+	if c.Pass.cache == nil {
+		c.Pass.cache = make(map[string][]byte)
+	}
+	c.Pass.cache[id] = output
+
+	return output, nil
 }
