@@ -5,26 +5,33 @@ import (
 	"strings"
 
 	"github.com/spf13/cobra"
-
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
 )
 
 func (c *Config) newSourcePathCmd() *cobra.Command {
 	sourcePathCmd := &cobra.Command{
 		Use:               "source-path [target]...",
-		Short:             "Print the path of a target in the source state",
+		Short:             "Print the source path of a target",
 		Long:              mustLongHelp("source-path"),
 		Example:           example("source-path"),
 		ValidArgsFunction: c.targetValidArgs,
-		RunE:              c.makeRunEWithSourceState(c.runSourcePathCmd),
+		RunE:              c.runSourcePathCmd,
 	}
 
 	return sourcePathCmd
 }
 
-func (c *Config) runSourcePathCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
+func (c *Config) runSourcePathCmd(cmd *cobra.Command, args []string) error {
 	if len(args) == 0 {
-		return c.writeOutputString(c.SourceDirAbsPath.String() + "\n")
+		sourceDirAbsPath, err := c.getSourceDirAbsPath(nil)
+		if err != nil {
+			return err
+		}
+		return c.writeOutputString(sourceDirAbsPath.String() + "\n")
+	}
+
+	sourceState, err := c.getSourceState(cmd.Context(), cmd)
+	if err != nil {
+		return err
 	}
 
 	sourceAbsPaths, err := c.sourceAbsPaths(sourceState, args)
