@@ -4,7 +4,7 @@ import (
 	"io/fs"
 	"testing"
 
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-vfs/v4/vfst"
 
@@ -14,17 +14,17 @@ import (
 func TestSymlinks(t *testing.T) {
 	for _, tc := range []struct {
 		name      string
-		extraRoot interface{}
+		extraRoot any
 		args      []string
-		tests     []interface{}
+		tests     []any
 	}{
 		{
 			name: "symlink_forward_slash_unix",
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.local/share/chezmoi/symlink_dot_symlink": ".dir/file",
 			},
 			args: []string{"~/.symlink"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.symlink",
 					vfst.TestModeType(fs.ModeSymlink),
 					vfst.TestSymlinkTarget(".dir/file"),
@@ -33,11 +33,11 @@ func TestSymlinks(t *testing.T) {
 		},
 		{
 			name: "symlink_forward_slash_windows",
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.local/share/chezmoi/symlink_dot_symlink": ".dir/file",
 			},
 			args: []string{"~/.symlink"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.symlink",
 					vfst.TestModeType(fs.ModeSymlink),
 					vfst.TestSymlinkTarget(".dir\\file"),
@@ -46,11 +46,11 @@ func TestSymlinks(t *testing.T) {
 		},
 		{
 			name: "symlink_backward_slash_windows",
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.local/share/chezmoi/symlink_dot_symlink": ".dir\\file",
 			},
 			args: []string{"~/.symlink"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.symlink",
 					vfst.TestModeType(fs.ModeSymlink),
 					vfst.TestSymlinkTarget(".dir\\file"),
@@ -59,11 +59,11 @@ func TestSymlinks(t *testing.T) {
 		},
 		{
 			name: "symlink_mixed_slash_windows",
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.local/share/chezmoi/symlink_dot_symlink": ".dir/subdir\\file",
 			},
 			args: []string{"~/.symlink"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.symlink",
 					vfst.TestModeType(fs.ModeSymlink),
 					vfst.TestSymlinkTarget(".dir\\subdir\\file"),
@@ -75,11 +75,14 @@ func TestSymlinks(t *testing.T) {
 			chezmoitest.SkipUnlessGOOS(t, tc.name)
 			chezmoitest.WithTestFS(t, nil, func(fileSystem vfs.FS) {
 				if tc.extraRoot != nil {
-					require.NoError(t, vfst.NewBuilder().Build(fileSystem, tc.extraRoot))
+					assert.NoError(t, vfst.NewBuilder().Build(fileSystem, tc.extraRoot))
 				}
-				require.NoError(t, newTestConfig(t, fileSystem).execute(append([]string{"apply"}, tc.args...)))
+				assert.NoError(
+					t,
+					newTestConfig(t, fileSystem).execute(append([]string{"apply"}, tc.args...)),
+				)
 				vfst.RunTests(t, fileSystem, "", tc.tests)
-				require.NoError(t, newTestConfig(t, fileSystem).execute([]string{"verify"}))
+				assert.NoError(t, newTestConfig(t, fileSystem).execute([]string{"verify"}))
 			})
 		})
 	}
