@@ -1,6 +1,7 @@
 package cmd
 
 import (
+	"reflect"
 	"strings"
 	"unicode"
 )
@@ -143,3 +144,20 @@ func upperSnakeCaseToCamelCaseMap[V any](m map[string]V) map[string]V {
 	}
 	return result
 }
+
+func flattenStringList(vpaths []any) []string {
+	var paths []string
+	for i := range vpaths {
+		switch path := vpaths[i].(type) {
+		case []string:
+			paths = append(paths, path...)
+		case string:
+			paths = append(paths, path)
+		case []any:
+			paths = append(paths, flattenStringList(path)...)
+		default:
+			panic("unknown type: " + reflect.TypeOf(path).String())
+		}
+	}
+	return paths
+}
