@@ -1,9 +1,10 @@
 package cmd
 
 import (
+	"io/fs"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
+	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-vfs/v4/vfst"
 
@@ -13,21 +14,21 @@ import (
 func TestVerifyCmd(t *testing.T) {
 	for _, tc := range []struct {
 		name        string
-		root        interface{}
+		root        any
 		expectedErr error
 	}{
 		{
 			name: "empty",
-			root: map[string]interface{}{
-				"/home/user": &vfst.Dir{
-					Perm: 0o700,
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": &vfst.Dir{
+					Perm: fs.ModePerm &^ chezmoitest.Umask,
 				},
 			},
 		},
 		{
 			name: "file",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".bashrc": &vfst.File{
 						Contents: []byte("# contents of .bashrc\n"),
 						Perm:     0o666 &^ chezmoitest.Umask,
@@ -39,7 +40,11 @@ func TestVerifyCmd(t *testing.T) {
 	} {
 		t.Run(tc.name, func(t *testing.T) {
 			chezmoitest.WithTestFS(t, tc.root, func(fileSystem vfs.FS) {
-				assert.Equal(t, tc.expectedErr, newTestConfig(t, fileSystem).execute([]string{"verify"}))
+				assert.Equal(
+					t,
+					tc.expectedErr,
+					newTestConfig(t, fileSystem).execute([]string{"verify"}),
+				)
 			})
 		})
 	}
